from guizero import App, Window, PushButton
from guizero.utilities import GUIZeroImage
from tkinter import PhotoImage


app = App(title="Main window")
app.icon = "guizero.gif"

window = Window(app, title="2nd window", visible=False)

open_window_button = PushButton(app, text="Open window", command=window.show)

close_window_button = PushButton(window, text="Close", command=window.hide)

app.display()




from guizero import App, TextBox, PushButton, Text, info

def go():
    info("hi", "hi " + textbox.value)

app = App()
text = Text(app, text="Enter your name")
textbox = TextBox(app, width=40)
button = PushButton(app, text="Hi", command=go)
app.display()



from guizero import App, TextBox, Text
from tkinter import INSERT

def key_pressed(key):
    details.value = "key pressed = {}, cursor pos = {}".format(
        textbox.value, 
        textbox.cursor_position
        )

app = App()
text = Text(app, text="Enter some text")
textbox = TextBox(app, width=40, command=key_pressed)
details = Text(app)
app.display()


from guizero import App, PushButton, Text


def get_color():
    color_selected = app.select_color("#000000")
    # color_selected = app.select_color()
    if color_selected is not None:
        color_name.value = "Color: " + color_selected
    else:
        color_name.value = ""


app = App()

PushButton(app, command=get_color, text="Get color")
color_name = Text(app)
color_name.value = "Color: #rrggbb"

app.display()



import pytest
from threading import Event
from guizero import App, Window, Text, system_config
from common_test import (
    schedule_after_test,
    schedule_repeat_test,
    display_test,
    events_test,
    cascading_enable_test,
    cascading_properties_test,
    inheriting_properties_test,
    full_screen_test,
    add_tk_widget_test,
    icon_test
    )

def test_default_values():
    a = App()
    w = Window(a)
    assert w.title == "guizero"
    assert w.width == 500
    assert w.height == 500
    assert w.layout == "auto"
    assert a.description > ""
    a.destroy()

def test_alt_values():
    a = App()
    w = Window(a, title = "foo", width = 666, height = 666, layout="grid")
    assert w.title == "foo"
    assert w.width == 666
    assert w.height == 666
    assert w.layout == "grid"
    a.destroy()

def test_getters_setters():
    a = App()
    w = Window(a)
    w.title = "bar"
    assert w.title == "bar"
    w.bg = "red"
    assert w.bg == "red"
    w.height = 666
    assert w.height == 666
    w.width = 666
    assert w.width == 666
    a.destroy()

def test_update():
    a = App()
    w = Window(a)
    # just testing it doesnt fail
    w.update()
    a.destroy()

def test_after_schedule():
    a = App()
    w = Window(a)
    schedule_after_test(a, w)
    a.destroy()

def test_repeat_schedule():
    a = App()
    w = Window(a)
    schedule_repeat_test(a, w)
    a.destroy()

def test_display():
    a = App()
    w = Window(a)
    display_test(w)
    a.destroy()

def test_enable():
    a = App()
    w = Window(a)
    t = Text(w)
    cascading_enable_test(a)
    cascading_enable_test(w)
    a.destroy()

def test_events():
    a = App()
    w = Window(a)
    events_test(w)
    a.destroy()

def test_cascading_properties():
    a = App()
    w = Window(a)
    cascading_properties_test(w)
    a.destroy()

def test_inheriting_properties():
    a = App()
    w = Window(a)
    inheriting_properties_test(w)
    a.destroy()

def test_full_screen():
    a = App()
    w = Window(a)
    full_screen_test(w)
    a.destroy()

def test_add_tk_widget():
    a = App()
    add_tk_widget_test(a)
    a.destroy()

def test_icon():
    a = App()
    w = Window(a)
    icon_test(w, "../examples/guizero.gif")
    a.destroy()

@pytest.mark.skipif(system_config.PIL_available == False,
                    reason="PIL not available")
def test_icon_jpg():
    a = App()
    w = Window(a)
    icon_test(w, "../examples/guizero.jpg")
    a.destroy()


import pytest
from threading import Event
from guizero import App, Text, Picture, system_config
from common_test import (
    schedule_after_test,
    schedule_repeat_test,
    display_test,
    events_test,
    cascading_enable_test,
    cascading_properties_test,
    inheriting_properties_test,
    full_screen_test,
    add_tk_widget_test,
    icon_test)

def test_default_values():
    a = App()
    assert a.title == "guizero"
    assert a.width == 500
    assert a.height == 500
    assert a.layout == "auto"
    assert a.description > ""
    a.destroy()

def test_alt_values():
    a = App(title = "foo", width = 666, height = 666, layout="grid")
    assert a.title == "foo"
    assert a.width == 666
    assert a.height == 666
    assert a.layout == "grid"
    a.destroy()

def test_getters_setters():
    a = App()
    a.title = "bar"
    assert a.title == "bar"
    a.bg = "red"
    assert a.bg == "red"
    a.height = 666
    assert a.height == 666
    a.width = 666
    assert a.width == 666
    a.destroy()

def test_update():
    a = App()
    # just testing it doesnt fail
    a.update()
    a.destroy()

def test_after_schedule():
    a = App()
    schedule_after_test(a, a)
    a.destroy()

def test_repeat_schedule():
    a = App()
    schedule_repeat_test(a, a)
    a.destroy()

def test_display():
    a = App()
    display_test(a)
    a.destroy()

def test_enable():
    a = App()
    t = Text(a)
    cascading_enable_test(a)
    a.destroy()

def test_events():
    a = App()
    events_test(a)
    a.destroy()

def test_when_resized():
    
    a = App()

    resize_event = Event()
    def callback():
        resize_event.set()

    def callback_params(event):
        assert event.width == 503
        assert event.height == 504
        resize_event.set()


    a.when_resized = callback
    a.resize(501, 502)
    assert resize_event.wait(1)
    resize_event.clear()
    
    a.when_resized = callback_params
    a.resize(503, 504)
    assert resize_event.wait(1)
    resize_event.clear()

    a.when_resized = None
    a.resize(505, 506)
    assert not resize_event.wait(0.1)

    a.destroy()

def test_cascading_properties():
    a = App()
    cascading_properties_test(a)
    a.destroy()

def test_inheriting_properties():
    a = App()
    inheriting_properties_test(a)
    a.destroy()

def test_full_screen():
    a = App()
    full_screen_test(a)
    a.destroy()

def test_add_tk_widget():
    a = App()
    add_tk_widget_test(a)
    a.destroy()

def test_icon():
    a = App()
    icon_test(a, "../examples/guizero.gif")
    a.destroy()

@pytest.mark.skipif(system_config.PIL_available == False,
                    reason="PIL not available")
def test_icon_jpg():
    a = App()
    icon_test(a, "../examples/guizero.jpg")
    a.destroy()


from guizero import App, Text

def double_click():
    double_click_me.value = "Thanks"
    app.after(1000, reset)

def reset():
    double_click_me.value ="Double click me"

app = App()

double_click_me = Text(app, text="Double click me")
double_click_me.when_double_clicked = double_click

app.display()


from guizero import App, PushButton, Text

def get_folder():
    folder_returned = app.select_folder()
    folder_name.value = folder_returned

app = App()

PushButton(app, command=get_folder, text="Get folder")
folder_name = Text(app)

app.display()


from guizero import App, TextBox, Text

def filter_numbers():
    numeric_filter = filter(str.isdigit, textbox.value)
    textbox.value = "".join(numeric_filter)

app = App()
text = Text(app, text="Enter numbers only")
textbox = TextBox(app, width=40, command=filter_numbers)
app.display()


from guizero import App, Text, PushButton

def update_size(e):
    app_size.value = "{}.{}".format(e.width, e.height)

def resize():
    app.resize(700,1000)

app = App()
app_size = Text(app)
app.when_resized = update_size

resize_button = PushButton(app, text="resize", command=resize)

app.display()


from guizero import App, Text, TitleBox
app = App()

titlebox = TitleBox(app, "Title of the box")

# change properties
# titlebox.text_size = 15
# titlebox.font = "courier new"
# titlebox.text_color = "red"

message = Text(titlebox,"Text inside a TitleBox")

app.display()
